Module graph

Module graph 

Structs

Edge
A directed, weighted edge between two nodes in the memory graph.
MemoryGraph
In-process memory graph backed by a SQLite WAL database.
Node
A typed node in the memory graph.
TraversalOptions
Options controlling how the memory graph is traversed.
TraversalResult
A single node returned by a graph traversal, with path metadata.