pub struct TraversalResult {
pub node: Node,
pub depth: usize,
pub weight: f64,
}Expand description
A single node returned by a graph traversal, with path metadata.
Fields
node: NodeThe reached node.
depth: usizeNumber of hops from the anchor node.
weight: f64Weight of the edge that connected this node to its parent in the traversal.