Structs
- Edge
- A directed, weighted edge between two nodes in the memory graph.
- Memory
Graph - In-process memory graph backed by a SQLite WAL database.
- Node
- A typed node in the memory graph.
- Traversal
Options - Options controlling how the memory graph is traversed.
- Traversal
Result - A single node returned by a graph traversal, with path metadata.